from yby.y_init import y_init
y_init()


'''
Alias of basic functions.
'''
        
##############################################################################

def y_inspect(module):
    
    '''
    Get module source code.

    PARAMETERS:
    -----------
    module     - module name

    RETURN:
    -------
    text       - module source code 
    '''

    import inspect

    text = inspect.getsource(module)

    return text

##############################################################################

def y_read(file):
    
    '''
    Get file content.

    PARAMETERS:
    -----------
    file       - file path

    RETURN:
    -------
    text       - file content
    '''

    with open(file, 'r') as fp:
        text = fp.read()

    return text

##############################################################################

def y_compile(file, py_ver='39'):
    
    '''
    Compile single file or files in a folder to pyc.
    Move
    
    PARAMETERS:
    -----------
    file       - a py file or a directory contains py files
    py_ver     - python version num, default is '39'
    
    RETURNS:
    --------
    the_list   - pyc abspath, list format
    '''
    
    import os
    import shutil
    import py_compile
    from yby.y_file import y_rename, y_isdir
    
    def move(file, dire):
        
        filename = os.path.split(file)[1]
        new_path = os.path.join(dire, filename)
        shutil.move(file, new_path)
        
        return file, new_path
    
    files = y_isdir(file)
    
    the_list = []
    
    for i in files:
        py_compile.compile(i)
        pyc_name = os.path.join(os.path.dirname(i), '__pycache__',  os.path.splitext(os.path.split(i)[1])[0]+'.cpython-'+py_ver+'.pyc')
        old_name, new_name = y_rename(pyc_name, '.cpython-'+py_ver, '', 'replace')
        old_name = old_name[0]
        new_name = new_name[0]
        file, new_path = move(new_name, os.path.dirname(os.path.dirname(new_name)))
        the_list.append(new_path)
        
    return the_list

##############################################################################




from yby.y_init import y_init
y_init()


###############################################################################

def y_points3d(x, y, z, value, cmap='jet', title=None):
    '''
    plot scatter on mayavi
    
    PARAMETERS:
    -----------
    x        - x array
    y        - y array
    z        - z array
    value    - value at coordinate(x, y, z)
    colot    - color map 
    title    - default is None
    '''
    
    from mayavi import mlab
    
    mlab.points3d(x, y, z, value, colormap=cmap)
    mlab.colorbar(orientation='vertical', nb_labels=6)

    mlab.title(title, height=0.9, size=1.5, color=(1,0,0))
    
    mlab.show()

###############################################################################



from yby.y_init import y_init
y_init()


##########################################################################

def y_addpath():
    
    '''
    Import project function instead of using functions defined in class
    '''
    
    import os
    import sys
    from yby.y_control import y_display
    
    y_display('','addpath')
    project_dir = input('Please input project function directory:')
    project_dir = project_dir.replace('"', '')
    
    sys.path.append(project_dir)
    
    assert os.path.exists(sys.path[-1]), 'Project function directory failed to append to sys.path.'

    y_display('','', '{} has been add to sys.path'.format(project_dir))
    y_display('','','end')
    
##############################################################################

def y_upload():

    '''
    Guide through upload packages to Pypi.

    PARAMETERS:
    -----------
    folder       - an empty root folder
    package      - a folder contains lots of modules
    '''

    from yby.y_text import y_license, y_readme, y_setup
    from yby.y_file import y_hotpath
    import shutil
    import os

    package = y_hotpath('Choose an uploading module:')
    folder = y_hotpath('Choose an empty folder:')
    
    assert os.listdir(folder)==[], 'yby: Root folder is not empty!'
    shutil.copytree(package,os.path.join(folder,os.path.split(package)[1]))

    license = y_license()
    readme = y_readme()

    name = os.path.split(package)[1]
    version = input('Please input version value:')
    setup = y_setup()
    setup = setup.replace('name="yby"', 'name="'+str(name)+'"')
    setup = setup.replace('version="0.0.0"', 'version="'+str(version)+'"')

    with open(os.path.join(folder, 'LICENSE.txt'), 'w', encoding='UTF-8') as fp:
        fp.write(license)
    with open(os.path.join(folder, 'README.md'), 'w', encoding='UTF-8') as fp:
        fp.write(readme)
    with open(os.path.join(folder, 'setup.py'), 'w', encoding='UTF-8') as fp:
        fp.write(setup)
            
    os.chdir(folder)
    #os.system('python setup.py check')
    os.system('python setup.py sdist bdist_wheel')
    #os.system('python -m pip install --user --upgrade twine')
    os.system('python -m twine upload dist/*')

##############################################################################



import setuptools
 
with open("README.md", "r", encoding="utf-8") as fp:
    long_description = fp.read()
    
with open("LICENSE.txt", "r", encoding="utf-8") as fp:
    long_license = fp.read()
    
setuptools.setup(
    name="yby",
    version="0.0.51",
    description='yanbingyang personal packages',
    url='https://pypi.org/user/Flyby_98/',
    author="Bingyang Yan",
    author_email="yanbingyang1998@outlook.com",
    license=long_license,
    install_requires=['setuptools',
                      'wheel',
                      'twine',
                      'numpy',
                      'pandas',
                      'scipy',
                      'matplotlib',
                      'cryptography',
                      'tqdm',
                      'glob2'],
    
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)

    


from yby.y_init import y_init
y_init()


###############################################################################

def y_lhs(minv, maxv, layers):
    
    '''
    Generate Latin Hypercube Samples.
    
    PARAMETERS:
    -----------
    minv       - minimum value list
    maxv       - maximum value list
    layers     - layers (points numbers)
    
    RETUNRS:
    --------
    points     - np.ndarray, (layers, len(minv))
    '''
    
    import numpy as np
    from pyDOE import lhs
    
    
    assert len(minv)==len(maxv), 'Minv and max have different length!'
    
    minv = np.array(minv)
    maxv = np.array(maxv)
    dims = len(minv)
    
    points = minv + (maxv - minv) * lhs(dims, layers)
    
    return points

###############################################################################
